import { Request, Response, BaseApiCore, constructUrl, executeHttpCall, constructHeaders } from '@managed-api/commons-core';
import { errorMessageBuilder } from './common';
import { customErrorHandlers, errorStrategyBuilderConstructor } from './errorStrategy';
;
export class GitlabApiCore extends BaseApiCore {
    constructor(options) {
        var _a, _b;
        super();
        this.options = options;
        if (!((_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy) && ((_b = this.options) === null || _b === void 0 ? void 0 : _b.errorStrategy) !== null) {
            this.setGlobalErrorStrategy((builder) => builder.retryOnRateLimiting(-1));
        }
        this.Repository = new RepositoryGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Commit = new CommitGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Epic = new EpicGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Issue = new IssueGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Link = new LinkGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Branch = new BranchGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.All = new AllGroup(this.Repository, this.Commit, this.Epic, this.Issue, this.Link, this.Branch);
    }
    setGlobalErrorStrategy(errorStrategy) {
        var _a;
        this.options = {
            ...(_a = this.options) !== null && _a !== void 0 ? _a : {},
            errorStrategy
        };
    }
    buildResponse(url, status, statusText, headers, body) {
        const response = new Response(url, status, statusText, headers, body);
        response.setBufferImplementation(this.implementation);
        return response;
    }
    getGlobalErrorStrategy() {
        var _a;
        return (_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy;
    }
}
class AllGroup {
    constructor(Repository, Commit, Epic, Issue, Link, Branch) {
        this.Repository = Repository;
        this.Commit = Commit;
        this.Epic = Epic;
        this.Issue = Issue;
        this.Link = Link;
        this.Branch = Branch;
    }
    /**
     * Get a list of repository branches from a project, sorted by name alphabetically.
     * Alternative usage: Branch.getBranches
     * Documentation: https://docs.gitlab.com/ee/api/branches.html#list-repository-branches
     * @param options Request options.
     */
    async getBranches(options) {
        return this.Branch.getBranches(options);
    }
    /**
     * Get a single project repository branch.
     * Alternative usage: Branch.getBranch
     * Documentation: https://docs.gitlab.com/ee/api/branches.html#get-single-repository-branch
     * @param options Request options.
     */
    async getBranch(options) {
        return this.Branch.getBranch(options);
    }
    /**
     * Create a new branch in the repository.
     * Alternative usage: Branch.createBranch
     * Documentation: https://docs.gitlab.com/ee/api/branches.html#create-repository-branch
     * @param options Request options.
     */
    async createBranch(options) {
        return this.Branch.createBranch(options);
    }
    /**
     * Delete a branch from the repository.
     * Alternative usage: Branch.deleteBranch
     * Documentation: https://docs.gitlab.com/ee/api/branches.html#delete-repository-branch
     * @param options Request options.
     */
    async deleteBranch(options) {
        return this.Branch.deleteBranch(options);
    }
    /**
     * Deletes all branches that are merged into the project’s default branch.
     * Alternative usage: Branch.deleteMergedBranches
     * Documentation: https://docs.gitlab.com/ee/api/branches.html#delete-merged-branches
     * @param options Request options.
     */
    async deleteMergedBranches(options) {
        return this.Branch.deleteMergedBranches(options);
    }
    /**
     * Get a list of a given issue’s linked issues, sorted by the relationship creation datetime (ascending). Issues are filtered according to the user authorizations.
     * Alternative usage: Link.Issue.getRelations
     * Documentation: https://docs.gitlab.com/ee/api/issue_links.html#list-issue-relations
     * @param options Request options.
     */
    async getIssueLinkRelations(options) {
        return this.Link.Issue.getRelations(options);
    }
    /**
     * Creates a two-way relation between two issues. The user must be allowed to update both issues to succeed.
     * Alternative usage: Link.Issue.createLink
     * Documentation: https://docs.gitlab.com/ee/api/issue_links.html#create-an-issue-link
     * @param options Request options.
     */
    async createIssueLink(options) {
        return this.Link.Issue.createLink(options);
    }
    /**
     * Deletes an issue link, thus removes the two-way relationship.
     * Alternative usage: Link.Issue.deleteLink
     * Documentation: https://docs.gitlab.com/ee/api/issue_links.html#delete-an-issue-link
     * @param options Request options.
     */
    async deleteIssueLink(options) {
        return this.Link.Issue.deleteLink(options);
    }
    /**
     * Get all issues the authenticated user has access to. By default it returns only issues created by the current user. To get all issues, use parameter scope=all.
     * Alternative usage: Issue.getIssues
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#list-issues
     * @param options Request options.
     */
    async getIssues(options) {
        return this.Issue.getIssues(options);
    }
    /**
     * Get a list of a group’s issues. If the group is private, credentials need to be provided for authorization.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#list-group-issues
     * @param options Request options.
     */
    async getGroupIssues(options) {
        return this.Issue.getGroupIssues(options);
    }
    /**
     * Get a list of a project’s issues. If the project is private, you need to provide credentials to authorize.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#list-project-issues
     * @param options Request options.
     */
    async getProjectIssues(options) {
        return this.Issue.getProjectIssues(options);
    }
    /**
     * Only for administrators. Get a single issue.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#single-issue
     * @param options Request options.
     */
    async getIssue(options) {
        return this.Issue.getIssue(options);
    }
    /**
     * Get a single project issue. If the project is private or the issue is confidential, you need to provide credentials to authorize.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#single-project-issue
     * @param options Request options.
     */
    async getProjectIssue(options) {
        return this.Issue.getProjectIssue(options);
    }
    /**
     * Creates a new project issue.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#new-issue
     * @param options Request options.
     */
    async createIssue(options) {
        return this.Issue.createIssue(options);
    }
    /**
     * Updates an existing project issue. This call is also used to mark an issue as closed.
     * At least one of the following parameters is required for the request to be successful:
     * :assignee_id
     * :assignee_ids
     * :confidential
     * :created_at
     * :description
     * :discussion_locked
     * :due_date
     * :issue_type
     * :labels
     * :milestone_id
     * :state_event
     * :title
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#new-issue
     * @param options Request options.
     */
    async editIssue(options) {
        return this.Issue.editIssue(options);
    }
    /**
     * Only for administrators and project owners. Deletes an issue.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#delete-an-issue
     * @param options Request options.
     */
    async deleteIssue(options) {
        return this.Issue.deleteIssue(options);
    }
    /**
     * Reorders an issue, you can see the results when sorting issues manually.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#reorder-an-issue
     * @param options Request options.
     */
    async reorderIssue(options) {
        return this.Issue.reorderIssue(options);
    }
    /**
     * Moves an issue to a different project.
     * If the target project is the source project or the user has insufficient permissions, an error message with status code 400 is returned.
     * If a given label or milestone with the same name also exists in the target project, it’s then assigned to the issue being moved.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#move-an-issue
     * @param options Request options.
     */
    async moveIssue(options) {
        return this.Issue.moveIssue(options);
    }
    /**
     * Clone the issue to given project. If the user has insufficient permissions, an error message with status code 400 is returned.
     * Copies as much data as possible as long as the target project contains equivalent labels, milestones, and so on.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#clone-an-issue
     * @param options Request options.
     */
    async cloneIssue(options) {
        return this.Issue.cloneIssue(options);
    }
    /**
     * Subscribes the authenticated user to an issue to receive notifications.
     * If the user is already subscribed to the issue, the status code 304 is returned.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#subscribe-to-an-issue
     * @param options Request options.
     */
    async subscribeToIssue(options) {
        return this.Issue.subscribeToIssue(options);
    }
    /**
     * Unsubscribes the authenticated user from the issue to not receive notifications from it.
     * If the user is not subscribed to the issue, the status code 304 is returned.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#unsubscribe-from-an-issue
     * @param options Request options.
     */
    async unsubscribeFromIssue(options) {
        return this.Issue.unsubscribeFromIssue(options);
    }
    /**
     * Manually creates a to-do item for the current user on an issue.
     * If there already exists a to-do item for the user on that issue, status code 304 is returned.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#create-a-to-do-item
     * @param options Request options.
     */
    async createIssueTodoItem(options) {
        return this.Issue.createTodoItem(options);
    }
    /**
     * Promotes an issue to an epic by adding a comment with the /promote quick action.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#promote-an-issue-to-an-epic
     * @param options Request options.
     */
    async promoteToEpic(options) {
        return this.Issue.promoteToEpic(options);
    }
    /**
     * Sets an estimated time of work for this issue.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#set-a-time-estimate-for-an-issue
     * @param options Request options.
     */
    async setTimeEstimateForIssue(options) {
        return this.Issue.setTimeEstimateForIssue(options);
    }
    /**
     * Resets the estimated time for this issue to 0 seconds.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#reset-the-time-estimate-for-an-issue
     * @param options Request options.
     */
    async resetTimeEstimateForIssue(options) {
        return this.Issue.resetTimeEstimateForIssue(options);
    }
    /**
     * Adds spent time for this issue.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#add-spent-time-for-an-issue
     * @param options Request options.
     */
    async addSpentTimeForIssue(options) {
        return this.Issue.addSpentTimeForIssue(options);
    }
    /**
     * Resets the total spent time for this issue to 0 seconds.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#reset-spent-time-for-an-issue
     * @param options Request options.
     */
    async resetTimeSpentForIssue(options) {
        return this.Issue.resetSpentTimeForIssue(options);
    }
    /**
     * If the project is private or the issue is confidential, you need to provide credentials to authorize.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#get-time-tracking-stats
     * @param options Request options.
     */
    async getTimeTrackingStatsForIssue(options) {
        return this.Issue.getTimeTrackingStatsForIssue(options);
    }
    /**
     * Get all the merge requests that are related to the issue.
     * If the project is private or the issue is confidential, you need to provide credentials to authorize.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#list-merge-requests-related-to-issue
     * @param options Request options.
     */
    async getMergeRequestsRelatedToIssue(options) {
        return this.Issue.getMergeRequestsRelatedToIssue(options);
    }
    /**
     * Get all merge requests that close a particular issue when merged.
     * If the project is private or the issue is confidential, you need to provide credentials to authorize.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#list-merge-requests-that-close-a-particular-issue-on-merge
     * @param options Request options.
     */
    async getMergeRequestsThatClosedAnIssue(options) {
        return this.Issue.getMergeRequestsThatClosedAnIssue(options);
    }
    /**
     * If the project is private or the issue is confidential, you need to provide credentials to authorize.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#participants-on-issues
     * @param options Request options.
     */
    async getIssueParticipants(options) {
        return this.Issue.getParticipants(options);
    }
    /**
     * Available only for administrators.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#get-user-agent-details
     * @param options Request options.
     */
    async getIssueUserAgentDetails(options) {
        return this.Issue.getUserAgentDetails(options);
    }
    /**
     * Gets all epics of the requested group and its subgroups.
     * Alternative usage: Epic.getEpicsForGroup
     * Documentation: https://docs.gitlab.com/ee/api/epics.html#list-epics-for-a-group
     * @param options Request options.
     */
    async getEpicsForGroup(options) {
        return this.Epic.getEpicsForGroup(options);
    }
    /**
     * Gets a single epic.
     * Alternative usage: Epic.getEpic
     * Documentation: https://docs.gitlab.com/ee/api/epics.html#single-epic
     * @param options Request options.
     */
    async getEpic(options) {
        return this.Epic.getEpic(options);
    }
    /**
     * Creates a new epic.
     * Alternative usage: Epic.createEpic
     * Documentation: https://docs.gitlab.com/ee/api/epics.html#new-epic
     * @param options Request options.
     */
    async createEpic(options) {
        return this.Epic.createEpic(options);
    }
    /**
     * Updates an epic.
     * Alternative usage: Epic.updateEpic
     * Documentation: https://docs.gitlab.com/ee/api/epics.html#update-epic
     * @param options Request options.
     */
    async updateEpic(options) {
        return this.Epic.updateEpic(options);
    }
    /**
     * Deletes an epic.
     * Alternative usage: Epic.deleteEpic
     * Documentation: https://docs.gitlab.com/ee/api/epics.html#delete-epic
     * @param options Request options.
     */
    async deleteEpic(options) {
        return this.Epic.deleteEpic(options);
    }
    /**
     * Manually creates a to-do item for the current user on an epic.
     * If there already exists a to-do item for the user on that epic, status code 304 is returned.
     * Alternative usage: Epic.createTodoItem
     * Documentation: https://docs.gitlab.com/ee/api/epics.html#create-a-to-do-item
     * @param options Request options.
     */
    async createEpicTodoItem(options) {
        return this.Epic.createTodoItem(options);
    }
    /**
     * Get a list of repository commits in a project.
     * Alternative usage: Commit.getCommits
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#list-repository-commits
     * @param options Request options.
     */
    async getCommits(options) {
        return this.Commit.getCommits(options);
    }
    /**
     * Create a commit by posting a JSON payload.
     * Alternative usage: Commit.createCommit
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#create-a-commit-with-multiple-files-and-actions
     * @param options Request options.
     */
    async createCommit(options) {
        return this.Commit.createCommit(options);
    }
    /**
     * Get a specific commit identified by the commit hash or name of a branch or tag.
     * Alternative usage: Commit.getCommit
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#get-a-single-commit
     * @param options Request options.
     */
    async getCommit(options) {
        return this.Commit.getCommit(options);
    }
    /**
     * Get all references (from branches or tags) a commit is pushed to.
     * The pagination parameters page and per_page can be used to restrict the list of references.
     * Alternative usage: Commit.getCommitReferences
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#get-references-a-commit-is-pushed-to
     * @param options Request options.
     */
    async getCommitReferences(options) {
        return this.Commit.getCommitReferences(options);
    }
    /**
     * Cherry-picks a commit to a given branch.
     * Alternative usage: Commit.cherryPickCommit
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#cherry-pick-a-commit
     * @param options Request options.
     */
    async cherryPickCommit(options) {
        return this.Commit.cherryPickCommit(options);
    }
    /**
     * Reverts a commit in a given branch.
     * Alternative usage: Commit.revertCommit
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#revert-a-commit
     * @param options Request options.
     */
    async revertCommit(options) {
        return this.Commit.revertCommit(options);
    }
    /**
     * Get the diff of a commit in a project.
     * Alternative usage: Commit.getCommitDiff
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#get-the-diff-of-a-commit
     * @param options Request options.
     */
    async getCommitDiff(options) {
        return this.Commit.getCommitDiff(options);
    }
    /**
     * Get the comments of a commit in a project.
     * Alternative usage: Commit.getComments
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#get-the-comments-of-a-commit
     * @param options Request options.
     */
    async getCommitComments(options) {
        return this.Commit.getComments(options);
    }
    /**
     * Adds a comment to a commit.
     * To post a comment in a particular line of a particular file, you must specify the full commit SHA, the path, the line, and line_type should be new.
     * Alternative usage: Commit.createComment
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#post-comment-to-commit
     * @param options Request options.
     */
    async createCommitComment(options) {
        return this.Commit.createComment(options);
    }
    /**
     * Get the discussions of a commit in a project.
     * Alternative usage: Commit.getDiscussions
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#get-the-discussions-of-a-commit
     * @param options Request options.
     */
    async getCommitDiscussions(options) {
        return this.Commit.getDiscussions(options);
    }
    /**
     * Get a list of merge requests related to the specified commit.
     * Alternative usage: Commit.getMergeRequests
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#list-merge-requests-associated-with-a-commit
     * @param options Request options.
     */
    async getCommitMergeRequests(options) {
        return this.Commit.getMergeRequests(options);
    }
    /**
     * Get the GPG signature from a commit, if it is signed.
     * For unsigned commits, it results in a 404 response: https://docs.gitlab.com/ee/user/project/repository/gpg_signed_commits/index.html
     * Alternative usage: Commit.getGPGSignature
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#get-gpg-signature-of-a-commit
     * @param options Request options.
     */
    async getCommitGPGSignature(options) {
        return this.Commit.getGPGSignature(options);
    }
    /**
     * List the statuses of a commit in a project.
     * The pagination parameters page and per_page can be used to restrict the list of references.
     * Alternative usage: Commit.Status.getStatuses
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#list-the-statuses-of-a-commit
     * @param options Request options.
     */
    async getCommitStatuses(options) {
        return this.Commit.Status.getStatuses(options);
    }
    /**
     * Adds or updates a build status of a commit.
     * Alternative usage: Commit.Status.createBuildStatus
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#post-the-build-status-to-a-commit
     * @param options Request options.
     */
    async createCommitBuildStatus(options) {
        return this.Commit.Status.createBuildStatus(options);
    }
    /**
     * Allows you to receive information about file in repository like name, size, content. File content is Base64 encoded.
     * Alternative usage: Repository.File.getFile
     * Documentation: https://docs.gitlab.com/ee/api/repository_files.html#get-file-from-repository
     * @param options Request options.
     */
    async getFileFromRepository(options) {
        return this.Repository.File.getFile(options);
    }
    /**
     * Allows you to receive blame information.
     * Each blame range contains lines and corresponding commit information.
     * Alternative usage: Repository.File.getFileBlame
     * Documentation: https://docs.gitlab.com/ee/api/repository_files.html#get-file-blame-from-repository
     * @param options Request options.
     */
    async getFileBlameFromRepository(options) {
        return this.Repository.File.getFileBlame(options);
    }
    /**
     * Get raw file from repository.
     * Alternative usage: Repository.File.getRawFile
     * Documentation: https://docs.gitlab.com/ee/api/repository_files.html#get-raw-file-from-repository
     * @param options Request options.
     */
    async getRawFileFromRepository(options) {
        return this.Repository.File.getRawFile(options);
    }
    /**
     * This allows you to create a single file.
     * For creating multiple files with a single request see the commits API: https://docs.gitlab.com/ee/api/commits.html#create-a-commit-with-multiple-files-and-actions
     * Alternative usage: Repository.File.createFile
     * Documentation: https://docs.gitlab.com/ee/api/repository_files.html#create-new-file-in-repository
     * @param options Request options.
     */
    async createFileInRepository(options) {
        return this.Repository.File.createFile(options);
    }
    /**
     * This allows you to update a single file.
     * For updating multiple files with a single request see the commits API: https://docs.gitlab.com/ee/api/commits.html#create-a-commit-with-multiple-files-and-actions
     * Alternative usage: Repository.File.updateFile
     * Documentation: https://docs.gitlab.com/ee/api/repository_files.html#update-existing-file-in-repository
     * @param options Request options.
     */
    async updateFileInRepository(options) {
        return this.Repository.File.updateFile(options);
    }
    /**
     * This allows you to delete a single file.
     * For deleting multiple files with a single request see the commits API: https://docs.gitlab.com/ee/api/commits.html#create-a-commit-with-multiple-files-and-actions
     * Alternative usage: Repository.File.deleteFile
     * Documentation: https://docs.gitlab.com/ee/api/repository_files.html#delete-existing-file-in-repository
     * @param options Request options.
     */
    async deleteFileInRepository(options) {
        return this.Repository.File.deleteFile(options);
    }
    /**
     * Get a list of repository files and directories in a project.
     * Alternative usage: Repository.getRepositoryTree
     * Documentation: https://docs.gitlab.com/ee/api/repositories.html#list-repository-tree
     * @param options Request options.
     */
    async getRepositoryTree(options) {
        return this.Repository.getRepositoryTree(options);
    }
    /**
     * Allows you to receive information about blob in repository like size and content. Blob content is Base64 encoded.
     * Alternative usage: Repository.getBlob
     * Documentation: https://docs.gitlab.com/ee/api/repositories.html#get-a-blob-from-repository
     * @param options Request options.
     */
    async getBlobFromRepository(options) {
        return this.Repository.getBlob(options);
    }
    /**
     * Get the raw file contents for a blob by blob SHA.
     * Alternative usage: Repository.getRawBlobContent
     * Documentation: https://docs.gitlab.com/ee/api/repositories.html#raw-blob-content
     * @param options Request options.
     */
    async getRawBlobContentFromRepository(options) {
        return this.Repository.getRawBlobContent(options);
    }
    /**
     * Get an archive of the repository. This endpoint has a rate limit threshold of 5 requests per minute for GitLab.com users.
     * Alternative usage: Repository.getFileArchive
     * Documentation: https://docs.gitlab.com/ee/api/repositories.html#get-file-archive
     * @param options Request options.
     */
    async getFileArchiveFromRepository(options) {
        return this.Repository.getFileArchive(options);
    }
    /**
     * Compare branches, tags or commits. Diffs can have an empty diff string if diff limits are reached.
     * Alternative usage: Repository.compare
     * Documentation: https://docs.gitlab.com/ee/api/repositories.html#compare-branches-tags-or-commits
     * @param options Request options.
     */
    async repositoryCompare(options) {
        return this.Repository.compare(options);
    }
    /**
     * Get repository contributors list.
     * Alternative usage: Repository.getContributors
     * Documentation: https://docs.gitlab.com/ee/api/repositories.html#contributors
     * @param options Request options.
     */
    async getRepositoryContributors(options) {
        return this.Repository.getContributors(options);
    }
    /**
     * Get the common ancestor for 2 or more refs (commit SHAs, branch names or tags).
     * Alternative usage: Repository.mergeBase
     * Documentation: https://docs.gitlab.com/ee/api/repositories.html#merge-base
     * @param options Request options.
     */
    async mergeRepositoryBase(options) {
        return this.Repository.mergeBase(options);
    }
    /**
     * Generate changelog data based on commits in a repository, without committing them to a changelog file.
     * Alternative usage: Repository.generateChangelog
     * Documentation: https://docs.gitlab.com/ee/api/repositories.html#generate-changelog-data
     * @param options Request options.
     */
    async generateRepositoryChangelog(options) {
        return this.Repository.generateChangelog(options);
    }
    /**
     * Generate changelog data based on commits in a repository.
     * The output of this process is a new section in a changelog file in the Git repository of the given project.
     * The output format is in Markdown, and can be customized.
     * Alternative usage: Repository.addChangelog
     * Documentation: https://docs.gitlab.com/ee/api/repositories.html#add-changelog-data-to-a-changelog-file
     * @param options Request options.
     */
    async addRepositoryChangelog(options) {
        return this.Repository.addChangelog(options);
    }
}
class RepositoryGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.File = new RepositoryFileGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Get a list of repository files and directories in a project.
     * Documentation: https://docs.gitlab.com/ee/api/repositories.html#list-repository-tree
     * @param options Request options.
     */
    async getRepositoryTree(options) {
        const { id, path, ref, recursive, per_page, pagination, page_token, headers, errorStrategy } = options;
        const queryParams = { path, ref, recursive, per_page, pagination, page_token };
        const request = new Request('GET', constructUrl(`/api/v4/projects/${encodeURIComponent(id)}/repository/tree`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Allows you to receive information about blob in repository like size and content. Blob content is Base64 encoded.
     * Documentation: https://docs.gitlab.com/ee/api/repositories.html#get-a-blob-from-repository
     * @param options Request options.
     */
    async getBlob(options) {
        const { id, sha, headers, errorStrategy } = options;
        const request = new Request('GET', `/api/v4/projects/${encodeURIComponent(id)}/repository/blobs/${encodeURIComponent(sha)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get the raw file contents for a blob by blob SHA.
     * Documentation: https://docs.gitlab.com/ee/api/repositories.html#raw-blob-content
     * @param options Request options.
     */
    async getRawBlobContent(options) {
        const { id, sha, headers, errorStrategy } = options;
        const request = new Request('GET', `/api/v4/projects/${encodeURIComponent(id)}/repository/blobs/${encodeURIComponent(sha)}/raw`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Get an archive of the repository. This endpoint has a rate limit threshold of 5 requests per minute for GitLab.com users.
     * Documentation: https://docs.gitlab.com/ee/api/repositories.html#get-file-archive
     * @param options Request options.
     */
    async getFileArchive(options) {
        const { id, sha, path, format, headers, errorStrategy } = options;
        const queryParams = { path, sha };
        const request = new Request('GET', constructUrl(`/api/v4/projects/${encodeURIComponent(id)}/repository/archive${format ? encodeURIComponent(format) : ''}`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Compare branches, tags or commits. Diffs can have an empty diff string if diff limits are reached.
     * Documentation: https://docs.gitlab.com/ee/api/repositories.html#compare-branches-tags-or-commits
     * @param options Request options.
     */
    async compare(options) {
        const { id, from, to, from_project_id, straight, headers, errorStrategy } = options;
        const queryParams = { from, to, from_project_id, straight };
        const request = new Request('GET', constructUrl(`/api/v4/projects/${encodeURIComponent(id)}/repository/compare`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get repository contributors list.
     * Documentation: https://docs.gitlab.com/ee/api/repositories.html#contributors
     * @param options Request options.
     */
    async getContributors(options) {
        const { id, order_by, sort, headers, errorStrategy } = options;
        const queryParams = { order_by, sort };
        const request = new Request('GET', constructUrl(`/api/v4/projects/${encodeURIComponent(id)}/repository/contributors`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get the common ancestor for 2 or more refs (commit SHAs, branch names or tags).
     * Documentation: https://docs.gitlab.com/ee/api/repositories.html#merge-base
     * @param options Request options.
     */
    async mergeBase(options) {
        const { id, refs, headers, errorStrategy } = options;
        const queryParams = { refs };
        const request = new Request('GET', constructUrl(`/api/v4/projects/${encodeURIComponent(id)}/repository/merge_base`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Generate changelog data based on commits in a repository, without committing them to a changelog file.
     * Documentation: https://docs.gitlab.com/ee/api/repositories.html#generate-changelog-data
     * @param options Request options.
     */
    async generateChangelog(options) {
        const { id, version, from, to, date, trailer, headers, errorStrategy } = options;
        const queryParams = { version, from, to, date, trailer };
        const request = new Request('GET', constructUrl(`/api/v4/projects/${encodeURIComponent(id)}/repository/changelog`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Generate changelog data based on commits in a repository.
     * The output of this process is a new section in a changelog file in the Git repository of the given project.
     * The output format is in Markdown, and can be customized.
     * Documentation: https://docs.gitlab.com/ee/api/repositories.html#add-changelog-data-to-a-changelog-file
     * @param options Request options.
     */
    async addChangelog(options) {
        const { id, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/api/v4/projects/${encodeURIComponent(id)}/repository/changelog`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RepositoryFileGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Allows you to receive information about file in repository like name, size, content. File content is Base64 encoded.
     * Documentation: https://docs.gitlab.com/ee/api/repository_files.html#get-file-from-repository
     * @param options Request options.
     */
    async getFile(options) {
        const { id, file_path, ref, headers, errorStrategy } = options;
        const queryParams = { ref };
        const request = new Request('GET', constructUrl(`/api/v4/projects/${encodeURIComponent(id)}/repository/files/${encodeURIComponent(file_path)}`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Allows you to receive blame information.
     * Each blame range contains lines and corresponding commit information.
     * Documentation: https://docs.gitlab.com/ee/api/repository_files.html#get-file-blame-from-repository
     * @param options Request options.
     */
    async getFileBlame(options) {
        const { id, file_path, ref, headers, errorStrategy } = options;
        const queryParams = { ref };
        const request = new Request('GET', constructUrl(`/api/v4/projects/${encodeURIComponent(id)}/repository/files/${encodeURIComponent(file_path)}/blame`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get raw file from repository.
     * Documentation: https://docs.gitlab.com/ee/api/repository_files.html#get-raw-file-from-repository
     * @param options Request options.
     */
    async getRawFile(options) {
        const { id, file_path, ref, headers, errorStrategy } = options;
        const queryParams = { ref };
        const request = new Request('GET', constructUrl(`/api/v4/projects/${encodeURIComponent(id)}/repository/files/${encodeURIComponent(file_path)}/raw`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * This allows you to create a single file.
     * For creating multiple files with a single request see the commits API: https://docs.gitlab.com/ee/api/commits.html#create-a-commit-with-multiple-files-and-actions
     * Documentation: https://docs.gitlab.com/ee/api/repository_files.html#create-new-file-in-repository
     * @param options Request options.
     */
    async createFile(options) {
        const { id, file_path, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/api/v4/projects/${encodeURIComponent(id)}/repository/files/${encodeURIComponent(file_path)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * This allows you to update a single file.
     * For updating multiple files with a single request see the commits API: https://docs.gitlab.com/ee/api/commits.html#create-a-commit-with-multiple-files-and-actions
     * Documentation: https://docs.gitlab.com/ee/api/repository_files.html#update-existing-file-in-repository
     * @param options Request options.
     */
    async updateFile(options) {
        const { id, file_path, body, headers, errorStrategy } = options;
        const request = new Request('PUT', `/api/v4/projects/${encodeURIComponent(id)}/repository/files/${encodeURIComponent(file_path)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * This allows you to delete a single file.
     * For deleting multiple files with a single request see the commits API: https://docs.gitlab.com/ee/api/commits.html#create-a-commit-with-multiple-files-and-actions
     * Documentation: https://docs.gitlab.com/ee/api/repository_files.html#delete-existing-file-in-repository
     * @param options Request options.
     */
    async deleteFile(options) {
        const { id, file_path, body, headers, errorStrategy } = options;
        const request = new Request('DELETE', `/api/v4/projects/${encodeURIComponent(id)}/repository/files/${encodeURIComponent(file_path)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class CommitGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Status = new CommitStatusGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Get a list of repository commits in a project.
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#list-repository-commits
     * @param options Request options.
     */
    async getCommits(options) {
        const { id, ref_name, since, until, path, all, with_stats, first_parent, order, trailers, headers, errorStrategy } = options;
        const queryParams = { ref_name, since, until, path, all, with_stats, first_parent, order, trailers };
        const request = new Request('GET', constructUrl(`/api/v4/projects/${encodeURIComponent(id)}/repository/commits`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Create a commit by posting a JSON payload.
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#create-a-commit-with-multiple-files-and-actions
     * @param options Request options.
     */
    async createCommit(options) {
        const { id, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/api/v4/projects/${encodeURIComponent(id)}/repository/commits`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get a specific commit identified by the commit hash or name of a branch or tag.
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#get-a-single-commit
     * @param options Request options.
     */
    async getCommit(options) {
        const { id, sha, stats, headers, errorStrategy } = options;
        const queryParams = { stats };
        const request = new Request('GET', constructUrl(`/api/v4/projects/${encodeURIComponent(id)}/repository/commits/${encodeURIComponent(sha)}`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get all references (from branches or tags) a commit is pushed to.
     * The pagination parameters page and per_page can be used to restrict the list of references.
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#get-references-a-commit-is-pushed-to
     * @param options Request options.
     */
    async getCommitReferences(options) {
        const { id, sha, type, page, per_page, headers, errorStrategy } = options;
        const queryParams = { type, page, per_page };
        const request = new Request('GET', constructUrl(`/api/v4/projects/${encodeURIComponent(id)}/repository/commits/${encodeURIComponent(sha)}/refs`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Cherry-picks a commit to a given branch.
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#cherry-pick-a-commit
     * @param options Request options.
     */
    async cherryPickCommit(options) {
        const { id, sha, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/api/v4/projects/${encodeURIComponent(id)}/repository/commits/${encodeURIComponent(sha)}/cherry_pick`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Reverts a commit in a given branch.
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#revert-a-commit
     * @param options Request options.
     */
    async revertCommit(options) {
        const { id, sha, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/api/v4/projects/${encodeURIComponent(id)}/repository/commits/${encodeURIComponent(sha)}/revert`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get the diff of a commit in a project.
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#get-the-diff-of-a-commit
     * @param options Request options.
     */
    async getCommitDiff(options) {
        const { id, sha, headers, errorStrategy } = options;
        const request = new Request('GET', `/api/v4/projects/${encodeURIComponent(id)}/repository/commits/${encodeURIComponent(sha)}/diff`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get the comments of a commit in a project.
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#get-the-comments-of-a-commit
     * @param options Request options.
     */
    async getComments(options) {
        const { id, sha, headers, errorStrategy } = options;
        const request = new Request('GET', `/api/v4/projects/${encodeURIComponent(id)}/repository/commits/${encodeURIComponent(sha)}/comments`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Adds a comment to a commit.
     * To post a comment in a particular line of a particular file, you must specify the full commit SHA, the path, the line, and line_type should be new.
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#post-comment-to-commit
     * @param options Request options.
     */
    async createComment(options) {
        const { id, sha, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/api/v4/projects/${encodeURIComponent(id)}/repository/commits/${encodeURIComponent(sha)}/comments`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get the discussions of a commit in a project.
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#get-the-discussions-of-a-commit
     * @param options Request options.
     */
    async getDiscussions(options) {
        const { id, sha, headers, errorStrategy } = options;
        const request = new Request('GET', `/api/v4/projects/${encodeURIComponent(id)}/repository/commits/${encodeURIComponent(sha)}/discussions`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get a list of merge requests related to the specified commit.
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#list-merge-requests-associated-with-a-commit
     * @param options Request options.
     */
    async getMergeRequests(options) {
        const { id, sha, headers, errorStrategy } = options;
        const request = new Request('GET', `/api/v4/projects/${encodeURIComponent(id)}/repository/commits/${encodeURIComponent(sha)}/merge_requests`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get the GPG signature from a commit, if it is signed. For unsigned commits, it results in a 404 response: https://docs.gitlab.com/ee/user/project/repository/gpg_signed_commits/index.html
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#get-gpg-signature-of-a-commit
     * @param options Request options.
     */
    async getGPGSignature(options) {
        const { id, sha, headers, errorStrategy } = options;
        const request = new Request('GET', `/api/v4/projects/${encodeURIComponent(id)}/repository/commits/${encodeURIComponent(sha)}/signature`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class CommitStatusGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * List the statuses of a commit in a project.
     * The pagination parameters page and per_page can be used to restrict the list of references.
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#list-the-statuses-of-a-commit
     * @param options Request options.
     */
    async getStatuses(options) {
        const { id, sha, ref, stage, name, all, headers, errorStrategy } = options;
        const queryParams = { ref, stage, name, all };
        const request = new Request('GET', constructUrl(`/api/v4/projects/${encodeURIComponent(id)}/repository/commits/${encodeURIComponent(sha)}/statuses`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Adds or updates a build status of a commit.
     * Documentation: https://docs.gitlab.com/ee/api/commits.html#post-the-build-status-to-a-commit
     * @param options Request options.
     */
    async createBuildStatus(options) {
        const { id, sha, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/api/v4/projects/${encodeURIComponent(id)}/statuses/${encodeURIComponent(sha)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class EpicGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Gets all epics of the requested group and its subgroups.
     * Documentation: https://docs.gitlab.com/ee/api/epics.html#list-epics-for-a-group
     * @param options Request options.
     */
    async getEpicsForGroup(options) {
        const { id, headers, errorStrategy, ...queryParams } = options;
        const request = new Request('GET', constructUrl(`/api/v4/groups/${encodeURIComponent(id)}/epics`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Gets a single epic.
     * Documentation: https://docs.gitlab.com/ee/api/epics.html#single-epic
     * @param options Request options.
     */
    async getEpic(options) {
        const { id, epic_iid, headers, errorStrategy } = options;
        const request = new Request('GET', `/api/v4/groups/${encodeURIComponent(id)}/epics/${encodeURIComponent(epic_iid)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Creates a new epic.
     * Documentation: https://docs.gitlab.com/ee/api/epics.html#new-epic
     * @param options Request options.
     */
    async createEpic(options) {
        const { id, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/api/v4/groups/${encodeURIComponent(id)}/epics`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Updates an epic.
     * Documentation: https://docs.gitlab.com/ee/api/epics.html#update-epic
     * @param options Request options.
     */
    async updateEpic(options) {
        const { id, epic_iid, body, headers, errorStrategy } = options;
        const request = new Request('PUT', `/api/v4/groups/${encodeURIComponent(id)}/epics/${encodeURIComponent(epic_iid)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Deletes an epic.
     * Documentation: https://docs.gitlab.com/ee/api/epics.html#delete-epic
     * @param options Request options.
     */
    async deleteEpic(options) {
        const { id, epic_iid, headers, errorStrategy } = options;
        const request = new Request('DELETE', `/api/v4/groups/${encodeURIComponent(id)}/epics/${encodeURIComponent(epic_iid)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Manually creates a to-do item for the current user on an epic.
     * If there already exists a to-do item for the user on that epic, status code 304 is returned.
     * Documentation: https://docs.gitlab.com/ee/api/epics.html#create-a-to-do-item
     * @param options Request options.
     */
    async createTodoItem(options) {
        const { id, epic_iid, headers, errorStrategy } = options;
        const request = new Request('POST', `/api/v4/groups/${encodeURIComponent(id)}/epics/${encodeURIComponent(epic_iid)}/todo`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IssueGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Get all issues the authenticated user has access to. By default it returns only issues created by the current user. To get all issues, use parameter scope=all.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#list-issues
     * @param options Request options.
     */
    async getIssues(options) {
        const { in_param, headers, errorStrategy, ...queryParams } = options || {};
        const request = new Request('GET', constructUrl(`/api/v4/issues?in=${in_param ? encodeURIComponent(in_param) : 'title,description'}`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get a list of a group’s issues. If the group is private, credentials need to be provided for authorization.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#list-group-issues
     * @param options Request options.
     */
    async getGroupIssues(options) {
        const { id, headers, errorStrategy, ...queryParams } = options;
        const request = new Request('GET', constructUrl(`/api/v4/groups/${encodeURIComponent(id)}/issues`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get a list of a project’s issues. If the project is private, you need to provide credentials to authorize.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#list-project-issues
     * @param options Request options.
     */
    async getProjectIssues(options) {
        const { id, headers, errorStrategy, ...queryParams } = options;
        const request = new Request('GET', constructUrl(`/api/v4/projects/${encodeURIComponent(id)}/issues`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Only for administrators. Get a single issue.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#single-issue
     * @param options Request options.
     */
    async getIssue(options) {
        const { id, headers, errorStrategy } = options;
        const request = new Request('GET', `/api/v4/issues/${encodeURIComponent(id)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get a single project issue. If the project is private or the issue is confidential, you need to provide credentials to authorize.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#single-project-issue
     * @param options Request options.
     */
    async getProjectIssue(options) {
        const { id, issue_iid, headers, errorStrategy } = options;
        const request = new Request('GET', `/api/v4/projects/${encodeURIComponent(id)}/issues/${encodeURIComponent(issue_iid)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Creates a new project issue.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#new-issue
     * @param options Request options.
     */
    async createIssue(options) {
        const { id, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/api/v4/projects/${encodeURIComponent(id)}/issues`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Updates an existing project issue. This call is also used to mark an issue as closed.
     * At least one of the following parameters is required for the request to be successful:
     * :assignee_id
     * :assignee_ids
     * :confidential
     * :created_at
     * :description
     * :discussion_locked
     * :due_date
     * :issue_type
     * :labels
     * :milestone_id
     * :state_event
     * :title
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#new-issue
     * @param options Request options.
     */
    async editIssue(options) {
        const { id, issue_iid, body, headers, errorStrategy } = options;
        const request = new Request('PUT', `/api/v4/projects/${encodeURIComponent(id)}/issues/${encodeURIComponent(issue_iid)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Only for administrators and project owners. Deletes an issue.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#delete-an-issue
     * @param options Request options.
     */
    async deleteIssue(options) {
        const { id, issue_iid, headers, errorStrategy } = options;
        const request = new Request('DELETE', `/api/v4/projects/${encodeURIComponent(id)}/issues/${encodeURIComponent(issue_iid)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Reorders an issue, you can see the results when sorting issues manually.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#reorder-an-issue
     * @param options Request options.
     */
    async reorderIssue(options) {
        const { id, issue_iid, body, headers, errorStrategy } = options;
        const request = new Request('PUT', `/api/v4/projects/${encodeURIComponent(id)}/issues/${encodeURIComponent(issue_iid)}/reorder`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Moves an issue to a different project.
     * If the target project is the source project or the user has insufficient permissions, an error message with status code 400 is returned.
     * If a given label or milestone with the same name also exists in the target project, it’s then assigned to the issue being moved.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#move-an-issue
     * @param options Request options.
     */
    async moveIssue(options) {
        const { id, issue_iid, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/api/v4/projects/${encodeURIComponent(id)}/issues/${encodeURIComponent(issue_iid)}/move`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Clone the issue to given project. If the user has insufficient permissions, an error message with status code 400 is returned.
     * Copies as much data as possible as long as the target project contains equivalent labels, milestones, and so on.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#clone-an-issue
     * @param options Request options.
     */
    async cloneIssue(options) {
        const { id, issue_iid, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/api/v4/projects/${encodeURIComponent(id)}/issues/${encodeURIComponent(issue_iid)}/clone`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Subscribes the authenticated user to an issue to receive notifications.
     * If the user is already subscribed to the issue, the status code 304 is returned.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#subscribe-to-an-issue
     * @param options Request options.
     */
    async subscribeToIssue(options) {
        const { id, issue_iid, headers, errorStrategy } = options;
        const request = new Request('POST', `/api/v4/projects/${encodeURIComponent(id)}/issues/${encodeURIComponent(issue_iid)}/subscribe`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Unsubscribes the authenticated user from the issue to not receive notifications from it.
     * If the user is not subscribed to the issue, the status code 304 is returned.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#unsubscribe-from-an-issue
     * @param options Request options.
     */
    async unsubscribeFromIssue(options) {
        const { id, issue_iid, headers, errorStrategy } = options;
        const request = new Request('POST', `/api/v4/projects/${encodeURIComponent(id)}/issues/${encodeURIComponent(issue_iid)}/unsubscribe`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Manually creates a to-do item for the current user on an issue.
     * If there already exists a to-do item for the user on that issue, status code 304 is returned.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#create-a-to-do-item
     * @param options Request options.
     */
    async createTodoItem(options) {
        const { id, issue_iid, headers, errorStrategy } = options;
        const request = new Request('POST', `/api/v4/projects/${encodeURIComponent(id)}/issues/${encodeURIComponent(issue_iid)}/todo`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Promotes an issue to an epic by adding a comment with the /promote quick action.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#promote-an-issue-to-an-epic
     * @param options Request options.
     */
    async promoteToEpic(options) {
        const { id, issue_iid, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/api/v4/projects/${encodeURIComponent(id)}/issues/${encodeURIComponent(issue_iid)}/notes`, constructHeaders(body, headers), body);
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Sets an estimated time of work for this issue.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#set-a-time-estimate-for-an-issue
     * @param options Request options.
     */
    async setTimeEstimateForIssue(options) {
        const { id, issue_iid, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/api/v4/projects/${encodeURIComponent(id)}/issues/${encodeURIComponent(issue_iid)}/time_estimate`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Resets the estimated time for this issue to 0 seconds.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#reset-the-time-estimate-for-an-issue
     * @param options Request options.
     */
    async resetTimeEstimateForIssue(options) {
        const { id, issue_iid, headers, errorStrategy } = options;
        const request = new Request('POST', `/api/v4/projects/${encodeURIComponent(id)}/issues/${encodeURIComponent(issue_iid)}/reset_time_estimate`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Adds spent time for this issue.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#add-spent-time-for-an-issue
     * @param options Request options.
     */
    async addSpentTimeForIssue(options) {
        const { id, issue_iid, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/api/v4/projects/${encodeURIComponent(id)}/issues/${encodeURIComponent(issue_iid)}/add_spent_time`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Resets the total spent time for this issue to 0 seconds.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#reset-spent-time-for-an-issue
     * @param options Request options.
     */
    async resetSpentTimeForIssue(options) {
        const { id, issue_iid, headers, errorStrategy } = options;
        const request = new Request('POST', `/api/v4/projects/${encodeURIComponent(id)}/issues/${encodeURIComponent(issue_iid)}/reset_spent_time`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * If the project is private or the issue is confidential, you need to provide credentials to authorize.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#get-time-tracking-stats
     * @param options Request options.
     */
    async getTimeTrackingStatsForIssue(options) {
        const { id, issue_iid, headers, errorStrategy } = options;
        const request = new Request('GET', `/api/v4/projects/${encodeURIComponent(id)}/issues/${encodeURIComponent(issue_iid)}/time_stats`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get all the merge requests that are related to the issue.
     * If the project is private or the issue is confidential, you need to provide credentials to authorize.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#list-merge-requests-related-to-issue
     * @param options Request options.
     */
    async getMergeRequestsRelatedToIssue(options) {
        const { id, issue_iid, headers, errorStrategy } = options;
        const request = new Request('GET', `/api/v4/projects/${encodeURIComponent(id)}/issues/${encodeURIComponent(issue_iid)}/related_merge_requests`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get all merge requests that close a particular issue when merged.
     * If the project is private or the issue is confidential, you need to provide credentials to authorize.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#list-merge-requests-that-close-a-particular-issue-on-merge
     * @param options Request options.
     */
    async getMergeRequestsThatClosedAnIssue(options) {
        const { id, issue_iid, headers, errorStrategy } = options;
        const request = new Request('GET', `/api/v4/projects/${encodeURIComponent(id)}/issues/${encodeURIComponent(issue_iid)}/closed_by`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * If the project is private or the issue is confidential, you need to provide credentials to authorize.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#participants-on-issues
     * @param options Request options.
     */
    async getParticipants(options) {
        const { id, issue_iid, headers, errorStrategy } = options;
        const request = new Request('GET', `/api/v4/projects/${encodeURIComponent(id)}/issues/${encodeURIComponent(issue_iid)}/participants`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Available only for administrators.
     * Documentation: https://docs.gitlab.com/ee/api/issues.html#get-user-agent-details
     * @param options Request options.
     */
    async getUserAgentDetails(options) {
        const { id, issue_iid, headers, errorStrategy } = options;
        const request = new Request('GET', `/api/v4/projects/${encodeURIComponent(id)}/issues/${encodeURIComponent(issue_iid)}/user_agent_detail`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class LinkGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Issue = new LinkIssueGroup(this.implementation, this.getGlobalErrorStrategy);
    }
}
class LinkIssueGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Get a list of a given issue’s linked issues, sorted by the relationship creation datetime (ascending). Issues are filtered according to the user authorizations.
     * Documentation: https://docs.gitlab.com/ee/api/issue_links.html#list-issue-relations
     * @param options Request options.
     */
    async getRelations(options) {
        const { id, issue_iid, headers, errorStrategy } = options;
        const request = new Request('GET', `/api/v4/projects/${encodeURIComponent(id)}/issues/${encodeURIComponent(issue_iid)}/links`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Creates a two-way relation between two issues. The user must be allowed to update both issues to succeed.
     * Documentation: https://docs.gitlab.com/ee/api/issue_links.html#create-an-issue-link
     * @param options Request options.
     */
    async createLink(options) {
        const { id, issue_iid, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/api/v4/projects/${encodeURIComponent(id)}/issues/${encodeURIComponent(issue_iid)}/links`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Deletes an issue link, thus removes the two-way relationship.
     * Documentation: https://docs.gitlab.com/ee/api/issue_links.html#delete-an-issue-link
     * @param options Request options.
     */
    async deleteLink(options) {
        const { id, issue_iid, issue_link_id, headers, errorStrategy } = options;
        const request = new Request('DELETE', `/api/v4/projects/${encodeURIComponent(id)}/issues/${encodeURIComponent(issue_iid)}/links/${encodeURIComponent(issue_link_id)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class BranchGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Get a list of repository branches from a project, sorted by name alphabetically.
     * Documentation: https://docs.gitlab.com/ee/api/branches.html#list-repository-branches
     * @param options Request options.
     */
    async getBranches(options) {
        const { id, headers, errorStrategy, ...queryParams } = options;
        const request = new Request('GET', constructUrl(`/api/v4/projects/${encodeURIComponent(id)}/repository/branches`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get a single project repository branch.
     * Documentation: https://docs.gitlab.com/ee/api/branches.html#get-single-repository-branch
     * @param options Request options.
     */
    async getBranch(options) {
        const { id, branch, headers, errorStrategy } = options;
        const request = new Request('GET', `/api/v4/projects/${encodeURIComponent(id)}/repository/branches/${encodeURIComponent(branch)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Create a new branch in the repository.
     * Documentation: https://docs.gitlab.com/ee/api/branches.html#create-repository-branch
     * @param options Request options.
     */
    async createBranch(options) {
        const { id, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/api/v4/projects/${encodeURIComponent(id)}/repository/branches`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Delete a branch from the repository.
     * Documentation: https://docs.gitlab.com/ee/api/branches.html#delete-repository-branch
     * @param options Request options.
     */
    async deleteBranch(options) {
        const { id, branch, headers, errorStrategy } = options;
        const request = new Request('DELETE', `/api/v4/projects/${encodeURIComponent(id)}/repository/branches/${encodeURIComponent(branch)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Deletes all branches that are merged into the project’s default branch.
     * Documentation: https://docs.gitlab.com/ee/api/branches.html#delete-merged-branches
     * @param options Request options.
     */
    async deleteMergedBranches(options) {
        const { id, headers, errorStrategy } = options;
        const request = new Request('DELETE', `/api/v4/projects/${encodeURIComponent(id)}/repository/merged_branches`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
