import { HeadersOption } from '@managed-api/commons-core';
import { Epic, TodoItem } from '../definitions/epic';
import { CommonError, ErrorStrategyOption } from '../errorStrategy';
export interface GetEpicsForGroupRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the group owned by the authenticated user.
     */
    id: string | number;
    /**
     * Return epics created by the given user id.
     */
    author_id?: number;
    /**
     * Return epics created by the user with the given username.
     */
    author_username?: string;
    /**
     * Return epics matching a comma-separated list of labels names. Label names from the epic group or a parent group can be used.
     */
    labels?: string;
    /**
     * If true, response returns more details for each label in labels field: :name, :color, :description, :description_html, :text_color. Default is false.
     */
    with_labels_details?: boolean;
    /**
     * Return epics ordered by created_at, updated_at, or title fields. Default is created_at.
     */
    order_by?: string;
    /**
     * Return epics sorted in asc or desc order. Default is desc.
     */
    sort?: string;
    /**
     * Search epics against their title and description.
     */
    search?: string;
    /**
     * Search epics against their state, possible filters: opened, closed and all, default: all.
     */
    state?: string;
    /**
     * Return epics created on or after the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z).
     */
    created_after?: string;
    /**
     * Return epics created on or before the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z).
     */
    created_before?: string;
    /**
     * Return epics updated on or after the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z).
     */
    updated_after?: string;
    /**
     * Return epics updated on or before the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z).
     */
    updated_before?: string;
    /**
     * Include epics from the requested group’s ancestors. Default is false.
     */
    include_ancestor_groups?: boolean;
    /**
     * Include epics from the requested group’s descendants. Default is true.
     */
    include_descendant_groups?: boolean;
    /**
     * Return epics reacted by the authenticated user by the given emoji. None returns epics not given a reaction. Any returns epics given at least one reaction.
     */
    my_reaction_emoji?: string;
    /**
     * Return epics that do not match the parameters supplied. Accepts: author_id, author_username.
     */
    not?: string;
}
export interface GetEpicsForGroupResponseOK extends Array<Epic> {
}
export interface GetEpicsForGroupResponseError extends CommonError {
}
export interface GetEpicRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the group owned by the authenticated user.
     */
    id: string | number;
    /**
     * The internal ID of the epic.
     */
    epic_iid: string | number;
}
export interface GetEpicResponseOK extends Epic {
}
export interface GetEpicResponseError extends CommonError {
}
export interface CreateEpicRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the group owned by the authenticated user.
     */
    id: string | number;
    body: {
        /**
         * The title of the epic.
         */
        title: string;
        /**
         * The comma-separated list of labels.
         */
        labels?: string;
        /**
         * The description of the epic. Limited to 1,048,576 characters.
         */
        description?: string;
        /**
         * The color of the epic. Introduced in GitLab 14.8, behind a feature flag named epic_highlight_color (disabled by default).
         */
        color?: string;
        /**
         * Whether the epic should be confidential.
         */
        confidential?: boolean;
        /**
         * When the epic was created. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z .
         * Requires administrator or project/group owner privileges (available in GitLab 13.5 and later).
         */
        created_at?: string;
        /**
         * Whether start date should be sourced from start_date_fixed or from milestones (in GitLab 11.3 and later).
         */
        start_date_is_fixed?: boolean;
        /**
         * The fixed start date of an epic (in GitLab 11.3 and later).
         */
        start_date_fixed?: string;
        /**
         * Whether due date should be sourced from due_date_fixed or from milestones (in GitLab 11.3 and later).
         */
        due_date_is_fixed?: boolean;
        /**
         * The fixed due date of an epic (in GitLab 11.3 and later).
         */
        due_date_fixed?: string;
        /**
         * The ID of a parent epic (in GitLab 11.11 and later).
         */
        parent_id?: string | number;
    };
}
export interface CreateEpicResponseOK extends Epic {
}
export interface CreateEpicResponseError extends CommonError {
}
export interface UpdateEpicRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the group owned by the authenticated user.
     */
    id: string | number;
    /**
     * The internal ID of the epic.
     */
    epic_iid: string | number;
    body: {
        /**
         * Comma-separated label names to add to an issue.
         */
        add_labels?: string;
        /**
         * Whether the epic should be confidential.
         */
        confidential?: boolean;
        /**
         * The description of the epic. Limited to 1,048,576 characters.
         */
        description?: string;
        /**
         * The fixed due date of an epic (in GitLab 11.3 and later).
         */
        due_date_fixed?: string;
        /**
         * Whether due date should be sourced from due_date_fixed or from milestones (in GitLab 11.3 and later).
         */
        due_date_is_fixed?: boolean;
        /**
         * The comma-separated list of labels.
         */
        labels?: string;
        /**
         * The ID of a parent epic (in GitLab 11.11 and later).
         */
        parent_id?: string | number;
        /**
         * Comma-separated label names to remove from an issue.
         */
        remove_labels?: string;
        /**
         * The fixed start date of an epic (in GitLab 11.3 and later).
         */
        start_date_fixed?: string;
        /**
         * Whether start date should be sourced from start_date_fixed or from milestones (in GitLab 11.3 and later).
         */
        start_date_is_fixed?: boolean;
        /**
         * State event for an epic. Set close to close the epic and reopen to reopen it (in GitLab 11.4 and later).
         */
        state_event?: string;
        /**
         * The title of the epic.
         */
        title: string;
        /**
         * When the epic was updated. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z .
         * Requires administrator or project/group owner privileges (available in GitLab 13.5 and later)
         */
        updated_at?: string;
        /**
         * The color of the epic. Introduced in GitLab 14.8, behind a feature flag named epic_highlight_color (disabled by default).
         */
        color?: string;
    };
}
export interface UpdateEpicResponseOK extends Epic {
}
export interface UpdateEpicResponseError extends CommonError {
}
export interface DeleteEpicRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the group owned by the authenticated user.
     */
    id: string | number;
    /**
     * The internal ID of the epic.
     */
    epic_iid: string | number;
}
export declare type DeleteEpicResponseOK = undefined;
export interface DeleteEpicResponseError extends CommonError {
}
export interface CreateTodoItemRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the group owned by the authenticated user.
     */
    id: string | number;
    /**
     * The internal ID of the epic.
     */
    epic_iid: string | number;
}
export interface CreateTodoItemResponseOK extends TodoItem {
}
export interface CreateTodoItemResponseError extends CommonError {
}
//# sourceMappingURL=epic.d.ts.map