import { HeadersOption } from '@managed-api/commons-core';
import { Commit } from '../definitions/commit';
import { RepositoryCompare, RepositoryContributor, RepositoryGenerateChangelog, RepositoryTreeBlob, RepositoryTreeItem } from '../definitions/repository';
import { CommonError, ErrorStrategyOption } from '../errorStrategy';
export interface GetRepositoryTreeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user.
     */
    id: string | number;
    /**
     * The path inside repository. Used to get content of subdirectories.
     */
    path?: string;
    /**
     * The name of a repository branch or tag or if not given the default branch.
     */
    ref?: string;
    /**
     * Boolean value used to get a recursive tree (false by default).
     */
    recursive?: boolean;
    /**
     * Number of results to show per page. If not specified, defaults to 20.
     */
    per_page?: number;
    /**
     * If set to keyset, use the new keyset pagination method.
     */
    pagination?: string;
    /**
     * The tree record ID at which to fetch the next page. Used only with keyset pagination.
     */
    page_token?: string;
}
export interface GetRepositoryTreeResponseOK extends Array<RepositoryTreeItem> {
}
export interface GetRepositoryTreeResponseError extends CommonError {
}
export interface GetBlobRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user.
     */
    id: string | number;
    /**
     * The blob SHA.
     */
    sha: string;
}
export interface GetBlobResponseOK extends RepositoryTreeBlob {
}
export interface GetBlobError extends CommonError {
}
export interface GetRawBlobContentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user.
     */
    id: string | number;
    /**
     * The blob SHA.
     */
    sha: string;
}
export declare type GetRawBlobContentResponseOK = string;
export interface GetRawBlobContentError extends CommonError {
}
export interface GetFileArchiveRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user.
     */
    id: string | number;
    /**
     * The commit SHA to download. A tag, branch reference, or SHA can be used.
     * This defaults to the tip of the default branch if not specified.
     */
    sha?: string;
    /**
     * The subpath of the repository to download. This defaults to the whole repository (empty string).
     */
    path?: string;
    /**
     * format is an optional suffix for the archive format.
     * Default is tar.gz. Options are tar.gz, tar.bz2, tbz, tbz2, tb2, bz2, tar, and zip.
     */
    format?: '.tar.gz' | '.tar.bz2' | '.tbz' | '.tbz2' | '.bz2' | '.tar' | '.zip';
}
export interface GetFileArchiveResponseOK extends ArrayBuffer {
}
export interface GetFileArchiveResponseError extends CommonError {
}
export interface CompareRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user.
     */
    id: string | number;
    /**
     * The commit SHA or branch name.
     */
    from: string;
    /**
     * The commit SHA or branch name.
     */
    to: string;
    /**
     * The ID to compare from.
     */
    from_project_id?: number;
    /**
     * Comparison method, true for direct comparison between from and to (from..to), false to compare using merge base (from…to)’.
     * Default is false.
     */
    straight?: boolean;
}
export interface CompareResponseOK extends RepositoryCompare {
}
export interface CompareResponseError extends CommonError {
}
export interface GetContributorsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user.
     */
    id: string | number;
    /**
     * Return contributors ordered by name, email, or commits (orders by commit date) fields. Default is commits.
     */
    order_by?: 'name' | 'email' | 'commits';
    /**
     * Return contributors sorted in asc or desc order. Default is asc.
     */
    sort?: 'asc' | 'desc';
}
export interface GetContributorsResponseOK extends Array<RepositoryContributor> {
}
export interface GetContributorsResponseError extends CommonError {
}
export interface MergeBaseRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user.
     */
    id: string | number;
    /**
     * The refs to find the common ancestor of, multiple refs can be passed.
     */
    refs: string[];
}
export interface MergeBaseResponseOK extends Commit {
}
export interface MergeBaseResponseError extends CommonError {
}
export interface AddChangelogRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user.
     */
    id: string | number;
    body: {
        /**
         * The version to generate the changelog for. The format must follow semantic versioning: https://semver.org/
         */
        version: string;
        /**
         * The start of the range of commits (as a SHA) to use for generating the changelog. This commit itself isn’t included in the list.
         */
        from?: string;
        /**
         * The end of the range of commits (as a SHA) to use for the changelog.
         * This commit is included in the list. Defaults to the branch specified in the branch attribute.
         */
        to?: string;
        /**
         * The date and time of the release, defaults to the current time.
         */
        date?: string;
        /**
         * The branch to commit the changelog changes to, defaults to the project’s default branch.
         */
        branch?: string;
        /**
         * The Git trailer to use for including commits, defaults to Changelog.
         */
        trailer?: string;
        /**
         * The file to commit the changes to, defaults to CHANGELOG.md.
         */
        file?: string;
        /**
         * The commit message to produce when committing the changes, defaults to Add changelog for version X where X is the value of the version argument.
         */
        message?: string;
    };
}
export declare type AddChangelogResponseOK = number;
export interface AddChangelogResponseError extends CommonError {
}
export interface GenerateChangelogRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user.
     */
    id: string | number;
    /**
     * The version to generate the changelog for. The format must follow semantic versioning: https://semver.org/
     */
    version: string;
    /**
     * The start of the range of commits (as a SHA) to use for generating the changelog. This commit itself isn’t included in the list.
     */
    from?: string;
    /**
     * The end of the range of commits (as a SHA) to use for the changelog.
     * This commit is included in the list. Defaults to the branch specified in the branch attribute.
     */
    to?: string;
    /**
     * The date and time of the release, defaults to the current time.
     */
    date?: string;
    /**
     * The branch to commit the changelog changes to, defaults to the project’s default branch.
     */
    branch?: string;
    /**
     * The Git trailer to use for including commits, defaults to Changelog.
     */
    trailer?: string;
    /**
     * The file to commit the changes to, defaults to CHANGELOG.md.
     */
    file?: string;
    /**
     * The commit message to produce when committing the changes, defaults to Add changelog for version X where X is the value of the version argument.
     */
    message?: string;
}
export interface GenerateChangelogResponseOK extends RepositoryGenerateChangelog {
}
export interface GenerateChangelogResponseError extends CommonError {
}
//# sourceMappingURL=repository.d.ts.map